Description Usage Arguments Details Author(s) References See Also Examples
Diagnostic plots highlight putative QTL loci and effects as well as providing graphical model assessment tools.
1 2 3 4 5 6 |
x |
An object of class |
object |
An object of class |
verbose |
Verbose summaries if |
ask |
Ask before each plot if |
cutoff |
Cutoff passed to |
... |
graphical parameters can be given as arguments to |
This generic plot routine takes an object of class
qb created by qb.mcmc and produces plots via
calls to several other plot routines. The generic
summary produces a summary, while the generic
print passes through to summary.
Brian S. Yandell, yandell@stat.wisc.edu
plot, print,
summary,
qb.mcmc,
qb.coda,
qb.loci,
qb.BayesFactor,
qb.hpdone,
qb.epistasis,
qb.diag
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.