Description Usage Arguments Details Author(s) References See Also Examples
Old (2006, R/qtlbim version 2.6) style qb objects had important
external objects, namely the cross object and the MCMC samples
in flat files that were loaded as needed. qb.legacy upgrades to
the new (2007) style qb object. The commands qb.remove
and qb.recover are useful to remove and restore old style
qb objects.
1 2 3 4 |
qbObject |
Object of class |
remove |
Remove external MCMC samples if |
verbose |
Print warning if |
external.only |
Remove only external MCMC samples if |
cross |
Object of class |
traitName |
Character string name of trait to recover. |
output.dir |
Character string with name of output directory (inferred if missing). |
n.thin |
Thining of MCMC chain used in |
n.burnin |
Burnin of MCMC chain used in |
algorithm |
Algorithm of MCMC chain used in |
genoupdate |
Genotype update flag for MCMC chain used in |
... |
Options passed to |
At the present time, qb.mcmc stores MCMC samples in
external files located in directory output.dir, whose name is
typically the traitName followed by the date. qb.remove
removes this directory along with the
qbObject. qb.recover attempts to recover the use of an
orphaned output.dir after a crash of R. These are fragile routines.
Brian S. Yandell
http://www.qtlbim.org
1 2 3 4 5 6 7 8 9 10 11 | ## Not run:
## Upgrade legacy qb object.
myqbObject <- qb.legacy(myqbObject)
## Recover qbExample for trait "bp" of cross "hyper" using default output.dir.
qbExample <- qb.recover(hyper, "bp")
## Remove internal qbExample and external output.dir.
qb.remove(qbExample)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.